"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.NumberInput = void 0;
var _react = require("react");
var _keycode = _interopRequireDefault(require("keycode"));
var _FormField = require("@instructure/ui-form-field/lib/FormField");
var _IconArrowOpenDownLine = require("@instructure/ui-icons/lib/IconArrowOpenDownLine.js");
var _IconArrowOpenUpLine2 = require("@instructure/ui-icons/lib/IconArrowOpenUpLine.js");
var _testable = require("@instructure/ui-testable/lib/testable.js");
var _omitProps = require("@instructure/ui-react-utils/lib/omitProps.js");
var _pickProps = require("@instructure/ui-react-utils/lib/pickProps.js");
var _callRenderProp = require("@instructure/ui-react-utils/lib/callRenderProp.js");
var _getInteraction = require("@instructure/ui-react-utils/lib/getInteraction.js");
var _withDeterministicId = require("@instructure/ui-react-utils/lib/DeterministicIdContext/withDeterministicId.js");
var _hasVisibleChildren = require("@instructure/ui-a11y-utils/lib/hasVisibleChildren.js");
var _emotion = require("@instructure/emotion");
var _styles = _interopRequireDefault(require("./styles"));
var _theme = _interopRequireDefault(require("./theme"));
var _props = require("./props");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _dec, _dec2, _dec3, _class, _NumberInput, _IconArrowOpenUpLine, _IconArrowOpenDownLin;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
/**
---
category: components
id: NumberInput
---
**/
let NumberInput = exports.NumberInput = (_dec = (0, _withDeterministicId.withDeterministicId)(), _dec2 = (0, _emotion.withStyle)(_styles.default, _theme.default), _dec3 = (0, _testable.testable)(), _dec(_class = _dec2(_class = _dec3(_class = (_NumberInput = class NumberInput extends _react.Component {
  constructor(...args) {
    super(...args);
    this.state = {
      hasFocus: false
    };
    this.ref = null;
    this._input = null;
    this._id = void 0;
    this.handleRef = el => {
      this.ref = el;
    };
    this.handleInputRef = element => {
      this._input = element;
      if (typeof this.props.inputRef === 'function') {
        this.props.inputRef(element);
      }
    };
    this.handleFocus = event => {
      this.setState({
        hasFocus: true
      });
      if (typeof this.props.onFocus === 'function') {
        this.props.onFocus(event);
      }
    };
    this.handleBlur = event => {
      this.setState({
        hasFocus: false
      });
      if (typeof this.props.onBlur === 'function') {
        this.props.onBlur(event);
      }
    };
    this.handleChange = event => {
      if (typeof this.props.onChange === 'function') {
        this.props.onChange(event, event.target.value);
      }
    };
    this.handleKeyDown = event => {
      const _this$props = this.props,
        onKeyDown = _this$props.onKeyDown,
        onDecrement = _this$props.onDecrement,
        onIncrement = _this$props.onIncrement;
      if (typeof onKeyDown === 'function') {
        onKeyDown(event);
      }
      if (event.keyCode === _keycode.default.codes.down) {
        event.preventDefault();
        if (typeof onDecrement === 'function') {
          onDecrement(event);
        }
      } else if (event.keyCode === _keycode.default.codes.up) {
        event.preventDefault();
        if (typeof onIncrement === 'function') {
          onIncrement(event);
        }
      }
    };
    this.handleClickUpArrow = event => {
      this.arrowClicked(event, this.props.onIncrement);
    };
    this.handleClickDownArrow = event => {
      this.arrowClicked(event, this.props.onDecrement);
    };
  }
  get id() {
    if (this.props.id) {
      return this.props.id;
    }
    if (!this._id) {
      this._id = this.props.deterministicId();
    }
    return this._id;
  }
  get invalid() {
    return !!this.props.messages && this.props.messages.some(message => message.type === 'error' || message.type === 'newError');
  }
  get interaction() {
    return (0, _getInteraction.getInteraction)({
      props: this.props
    });
  }
  componentDidMount() {
    var _this$props$makeStyle, _this$props2;
    (_this$props$makeStyle = (_this$props2 = this.props).makeStyles) === null || _this$props$makeStyle === void 0 ? void 0 : _this$props$makeStyle.call(_this$props2, this.makeStyleVariables);
  }
  componentDidUpdate() {
    var _this$props$makeStyle2, _this$props3;
    (_this$props$makeStyle2 = (_this$props3 = this.props).makeStyles) === null || _this$props$makeStyle2 === void 0 ? void 0 : _this$props$makeStyle2.call(_this$props3, this.makeStyleVariables);
  }
  get makeStyleVariables() {
    return {
      interaction: this.interaction,
      hasFocus: this.state.hasFocus,
      invalid: this.invalid
    };
  }
  arrowClicked(event, callback) {
    const interaction = this.interaction;
    event.preventDefault();
    if (interaction === 'enabled') {
      var _this$_input;
      (_this$_input = this._input) === null || _this$_input === void 0 ? void 0 : _this$_input.focus();
      if (typeof callback === 'function') {
        callback(event);
      }
    }
  }
  renderArrows(customIcons) {
    var _this$props$styles, _this$props$styles2, _this$props$styles3;
    return (0, _jsxRuntime.jsxs)("span", {
      css: (_this$props$styles = this.props.styles) === null || _this$props$styles === void 0 ? void 0 : _this$props$styles.arrowContainer,
      children: [(0, _jsxRuntime.jsx)("button", {
        "aria-hidden": true,
        css: (_this$props$styles2 = this.props.styles) === null || _this$props$styles2 === void 0 ? void 0 : _this$props$styles2.arrow,
        onMouseDown: this.handleClickUpArrow,
        tabIndex: -1,
        type: "button",
        children: customIcons !== null && customIcons !== void 0 && customIcons.increase ? (0, _callRenderProp.callRenderProp)(customIcons.increase) : _IconArrowOpenUpLine || (_IconArrowOpenUpLine = (0, _jsxRuntime.jsx)(_IconArrowOpenUpLine2.IconArrowOpenUpLine, {}))
      }), (0, _jsxRuntime.jsx)("button", {
        "aria-hidden": true,
        css: (_this$props$styles3 = this.props.styles) === null || _this$props$styles3 === void 0 ? void 0 : _this$props$styles3.arrow,
        onMouseDown: this.handleClickDownArrow,
        tabIndex: -1,
        type: "button",
        children: customIcons !== null && customIcons !== void 0 && customIcons.decrease ? (0, _callRenderProp.callRenderProp)(customIcons.decrease) : _IconArrowOpenDownLin || (_IconArrowOpenDownLin = (0, _jsxRuntime.jsx)(_IconArrowOpenDownLine.IconArrowOpenDownLine, {}))
      })]
    });
  }
  render() {
    var _this$props$styles4, _this$props$styles5, _this$props$styles6;
    const _this$props4 = this.props,
      renderLabel = _this$props4.renderLabel,
      display = _this$props4.display,
      placeholder = _this$props4.placeholder,
      isRequired = _this$props4.isRequired,
      showArrows = _this$props4.showArrows,
      value = _this$props4.value,
      width = _this$props4.width,
      styles = _this$props4.styles,
      allowStringValue = _this$props4.allowStringValue,
      renderIcons = _this$props4.renderIcons,
      margin = _this$props4.margin;
    const interaction = this.interaction;
    const rawLabel = (0, _callRenderProp.callRenderProp)(renderLabel);
    const label = (0, _hasVisibleChildren.hasVisibleChildren)(rawLabel) ? (0, _jsxRuntime.jsxs)(_react.Fragment, {
      children: [rawLabel, isRequired && (0, _jsxRuntime.jsxs)("span", {
        css: this.invalid ? styles === null || styles === void 0 ? void 0 : styles.requiredInvalid : {},
        "aria-hidden": true,
        children: [' ', "*"]
      })]
    }) : rawLabel;
    return (0, _jsxRuntime.jsx)(_FormField.FormField, {
      ...(0, _pickProps.pickProps)(this.props, _FormField.FormField.allowedProps),
      label: label,
      inline: display === 'inline-block',
      id: this.id,
      elementRef: this.handleRef,
      margin: margin,
      children: (0, _jsxRuntime.jsx)("span", {
        css: (_this$props$styles4 = this.props.styles) === null || _this$props$styles4 === void 0 ? void 0 : _this$props$styles4.inputWidth,
        style: width ? {
          width
        } : void 0,
        children: (0, _jsxRuntime.jsxs)("span", {
          css: (_this$props$styles5 = this.props.styles) === null || _this$props$styles5 === void 0 ? void 0 : _this$props$styles5.inputContainer,
          children: [(0, _jsxRuntime.jsx)("input", {
            ...(0, _omitProps.omitProps)(this.props, [..._FormField.FormField.allowedProps, ...NumberInput.allowedProps]),
            css: (_this$props$styles6 = this.props.styles) === null || _this$props$styles6 === void 0 ? void 0 : _this$props$styles6.input,
            "aria-invalid": this.invalid ? 'true' : void 0,
            id: this.id,
            type: allowStringValue ? 'text' : 'number',
            inputMode: this.props.inputMode,
            placeholder: placeholder,
            ref: this.handleInputRef,
            required: isRequired,
            value: value,
            disabled: interaction === 'disabled',
            readOnly: interaction === 'readonly',
            onFocus: this.handleFocus,
            onBlur: this.handleBlur,
            onChange: this.handleChange,
            onKeyDown: this.handleKeyDown
          }), showArrows ? this.renderArrows(renderIcons) : null]
        })
      })
    });
  }
}, _NumberInput.displayName = "NumberInput", _NumberInput.componentId = 'NumberInput', _NumberInput.allowedProps = _props.allowedProps, _NumberInput.propTypes = _props.propTypes, _NumberInput.defaultProps = {
  // Leave interaction default undefined so that `disabled` and `readOnly` can also be supplied
  interaction: void 0,
  messages: [],
  isRequired: false,
  showArrows: true,
  size: 'medium',
  display: 'block',
  textAlign: 'start',
  inputMode: 'numeric',
  allowStringValue: false
}, _NumberInput)) || _class) || _class) || _class);
var _default = exports.default = NumberInput;